=== modified file 'drizzled/module/loader.cc'
--- drizzled/module/loader.cc	2011-01-10 06:17:57 +0000
+++ drizzled/module/loader.cc	2011-01-18 05:29:46 +0000
@@ -370,12 +370,12 @@
   /*
     Now we initialize all remaining plugins
   */
-  module::Registry::ModuleMap::const_iterator modules=
-    registry.getModulesMap().begin();
+  module::Registry::ModuleList module_list= registry.getList();
+  module::Registry::ModuleList::iterator modules= module_list.begin();
     
-  while (modules != registry.getModulesMap().end())
+  while (modules != module_list.end())
   {
-    module::Module *module= (*modules).second;
+    module::Module *module= *modules;
     ++modules;
     if (module->isInited == false)
     {

=== modified file 'drizzled/module/registry.cc'
--- drizzled/module/registry.cc	2011-01-18 03:24:01 +0000
+++ drizzled/module/registry.cc	2011-01-18 05:29:46 +0000
@@ -107,10 +107,62 @@
 
   module_registry_[add_str]= handle;
 
+  VertexDesc handle_vertex;
   Vertex vertex_info(add_str, handle);
 
-  VertexDesc handle_vertex= boost::add_vertex(depend_graph_);
+  /* It's possible we could have added a vertex without a module attached
+     as part of adding dependency edges */
+  bool found_vertex= false;
+  vertex_iter vertexes= boost::vertices(depend_graph_).first;
+  while (vertexes != vertices(depend_graph_).second)
+  {
+    if (properties(*vertexes).getName() == add_str)
+    {
+      found_vertex= true;
+      break;
+    }
+    ++vertexes;
+  }
+  if (found_vertex)
+  {
+    handle_vertex= *vertexes;
+  }
+  else
+  {
+    handle_vertex= boost::add_vertex(depend_graph_);
+  }
   properties(handle_vertex)= vertex_info;
+
+
+  Module::Depends::const_iterator handle_deps= handle->getDepends().begin();
+  while (handle_deps != handle->getDepends().end())
+  {
+    std::string dep_str((*handle_deps));
+    transform(dep_str.begin(), dep_str.end(),
+              dep_str.begin(), ::tolower);
+
+    bool found_dep= false;
+    vertex_iter it= boost::vertices(depend_graph_).first;
+    while (it != vertices(depend_graph_).second)
+    {
+      if (properties(*it).getName() == dep_str)
+      {
+        found_dep= true;
+        add_edge(handle_vertex, *it, depend_graph_);
+        break;
+      }
+      ++it;
+    }
+    if (not found_dep)
+    {
+      Vertex dep_vertex_info(dep_str);
+      VertexDesc dep_vertex= boost::add_vertex(depend_graph_);
+      properties(dep_vertex)= dep_vertex_info;
+    }
+
+    ++handle_deps;
+  }
+
 }
 
 void module::Registry::remove(module::Module *handle)
@@ -133,24 +185,27 @@
   assert(arg.size() == plugin_registry.size());
 }
 
-vector<module::Module *> module::Registry::getList(bool active)
+module::Registry::ModuleList module::Registry::getList()
 {
-  module::Module *plugin= NULL;
-
   std::vector<module::Module *> plugins;
-  plugins.reserve(module_registry_.size());
-
-  ModuleMap::iterator map_iter;
-  for (map_iter= module_registry_.begin();
-       map_iter != module_registry_.end();
-       map_iter++)
+
+  std::cout << "In module::Registry::getList" << std::endl;
+  
+  VertexList vertex_list;
+
+  boost::topological_sort(depend_graph_, std::back_inserter(vertex_list));
+
+  std::cout << "plugin load ordering: ";
+  for (VertexList::iterator i = vertex_list.begin();
+       i != vertex_list.end(); ++i)
   {
-    plugin= (*map_iter).second;
-    if (active)
-      plugins.push_back(plugin);
-    else if (plugin->isInited)
-      plugins.push_back(plugin);
+    std::cout << properties(*i).getName() << " ";
+    if (properties(*i).getModule() != NULL)
+    {
+      plugins.push_back(properties(*i).getModule());
+    }  
   }
+  std::cout << std::endl;
 
   return plugins;
 }

=== modified file 'drizzled/module/registry.h'
--- drizzled/module/registry.h	2011-01-18 03:24:01 +0000
+++ drizzled/module/registry.h	2011-01-18 05:29:46 +0000
@@ -60,6 +60,7 @@
 
   typedef std::map<std::string, Library *> LibraryMap;
   typedef std::map<std::string, Module *> ModuleMap;
+  typedef std::vector<Module *> ModuleList;
 private:
   LibraryMap library_registry_;
   ModuleMap module_registry_;
@@ -102,7 +103,7 @@
 
   void remove(Module *module);
 
-  std::vector<Module *> getList(bool active);
+  std::vector<Module *> getList();
 
   const plugin::Plugin::map &getPluginsMap() const
   {

=== modified file 'drizzled/module/vertex.h'
--- drizzled/module/vertex.h	2011-01-18 03:24:01 +0000
+++ drizzled/module/vertex.h	2011-01-18 05:29:46 +0000
@@ -56,6 +56,10 @@
     name_(""),
     module_(NULL)
   { }
+  explicit Vertex(const std::string& name) :
+    name_(name),
+    module_(NULL)
+  { }
   Vertex(const std::string& name, Module *module) :
     name_(name),
     module_(module)
@@ -74,7 +78,11 @@
   {
     return name_;
   }
-  const Module* getModule() const
+  void setModule(Module *module)
+  {
+    module_= module;
+  }
+  Module* getModule()
   {
     return module_;
   }

=== modified file 'plugin/registry_dictionary/modules.cc'
--- plugin/registry_dictionary/modules.cc	2010-12-20 16:56:48 +0000
+++ plugin/registry_dictionary/modules.cc	2011-01-18 05:29:46 +0000
@@ -51,7 +51,7 @@
   plugin::TableFunction::Generator(arg)
 {
   module::Registry &registry= module::Registry::singleton();
-  modules= registry.getList(true);
+  modules= registry.getList();
   it= modules.begin();
 }
 

=== modified file 'plugin/registry_dictionary/modules.h'
--- plugin/registry_dictionary/modules.h	2010-12-18 04:43:40 +0000
+++ plugin/registry_dictionary/modules.h	2011-01-18 05:29:46 +0000
@@ -29,8 +29,8 @@
 
   class Generator : public drizzled::plugin::TableFunction::Generator 
   {
-    std::vector<drizzled::module::Module *> modules;
-    std::vector<drizzled::module::Module *>::iterator it;
+    drizzled::module::Registry::ModuleList modules;
+    drizzled::module::Registry::ModuleList::iterator it;
 
   public:
     Generator(drizzled::Field **arg);

